package com.ruoyi.oa.mapper;

import java.util.List;
import com.ruoyi.oa.domain.CmcContractPaid;

/**
 * 实际回款Mapper接口
 * 
 * @author cmc
 * @date 2025-02-12
 */
public interface CmcContractPaidMapper 
{
    /**
     * 查询实际回款
     * 
     * @param paidId 实际回款主键
     * @return 实际回款
     */
    public CmcContractPaid selectCmcContractPaidByPaidId(Long paidId);

    /**
     * 查询实际回款列表
     * 
     * @param cmcContractPaid 实际回款
     * @return 实际回款集合
     */
    public List<CmcContractPaid> selectCmcContractPaidList(CmcContractPaid cmcContractPaid);

    /**
     * 新增实际回款
     * 
     * @param cmcContractPaid 实际回款
     * @return 结果
     */
    public int insertCmcContractPaid(CmcContractPaid cmcContractPaid);

    /**
     * 修改实际回款
     * 
     * @param cmcContractPaid 实际回款
     * @return 结果
     */
    public int updateCmcContractPaid(CmcContractPaid cmcContractPaid);

    /**
     * 删除实际回款
     * 
     * @param contractId 实际回款主键
     * @return 结果
     */
    public int deleteCmcContractPaidByContractId(String contractId);

    /**
     * 批量删除实际回款
     * 
     * @param contractIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCmcContractPaidByContractIds(String[] contractIds);
}
